docs.rs failed to build hashing-serializer-0.2.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
hashing-serializer-0.2.0-pre.0
An implementation of [serde::Serializer] serializing directly into a hash digest (anything implementing [digest::Update]).
use Digest;
use SigningKey;
use Serialize;
use Sha256;
use HashingSerializer;
let sk = from_slice.unwrap;
let vk = sk.verifying_key;
let mut digest = new;
let serializer = HashingSerializer ;
vk.serialize.unwrap;